***************
Getting Started
***************

Prerequisites
=============

You will need Python 3.6 or later, including the pip module.

Installation
============

Install from PyPi
-----------------

.. code-block:: bash

    pip install --user spoonbill


Install from GitHub
-------------------

.. code-block:: bash

    pip install --user https://github.com/open-contracting/spoonbill.git#egg=spoonbill

Usage
=====

.. code-block:: bash

    spoonbill -h

will print general help information.

Python Version Support
======================

This code supports Python 3.6 (and later).

Python 3.5 and earlier (including Python 2) are not supported, because they are
end of life, and some of the dependencies do not support them.
